<?php

namespace Litecms\File\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\File\Models\Server;

class ServerPolicy
{

    /**
     * Determine if the given user can view the server.
     *
     * @param UserPolicy $user
     * @param Server $server
     *
     * @return bool
     */
    public function view(UserPolicy $user, Server $server)
    {
        if ($user->canDo('file.server.view') && $user->isAdmin()) {
            return true;
        }

        return $server->user_id == user_id() && $server->user_type == user_type();
    }

    /**
     * Determine if the given user can create a server.
     *
     * @param UserPolicy $user
     * @param Server $server
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('file.server.create');
    }

    /**
     * Determine if the given user can update the given server.
     *
     * @param UserPolicy $user
     * @param Server $server
     *
     * @return bool
     */
    public function update(UserPolicy $user, Server $server)
    {
        if ($user->canDo('file.server.edit') && $user->isAdmin()) {
            return true;
        }

        return $server->user_id == user_id() && $server->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given server.
     *
     * @param UserPolicy $user
     * @param Server $server
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Server $server)
    {
        return $server->user_id == user_id() && $server->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given server.
     *
     * @param UserPolicy $user
     * @param Server $server
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Server $server)
    {
        if ($user->canDo('file.server.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given server.
     *
     * @param UserPolicy $user
     * @param Server $server
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Server $server)
    {
        if ($user->canDo('file.server.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
